@@ -9,7 +9,7 @@ from .data_manager import (
 __all__ = [
     'fetch_data_files',
     'get_charset_files',
-    'get_palette_files'
+    'get_palette_files',
     'get_testdata_files',
     'get_testdata_file',
 ]
