@@ -84,11 +84,11 @@ class Encoder:
         module = import_module(import_path[0])
 
         # `is_available(UID)` is required for plugins
-        if module.is_available(self.UID):  # type: ignore[attr-defined]
+        if module.is_available(self.UID):
             self._available[label] = getattr(module, import_path[1])
         else:
             # `ENCODER_DEPENDENCIES[UID]` is required for plugins
-            deps = module.ENCODER_DEPENDENCIES  # type: ignore[attr-defined]
+            deps = module.ENCODER_DEPENDENCIES
             self._unavailable[label] = deps[self.UID]
 
     @staticmethod
@@ -131,10 +131,7 @@ class Encoder:
                 multi-sample data.
 
             * :class:`~pydicom.dataset.Dataset`: the dataset containing
-              the compressed or uncompressed *Pixel Data* to be encoded. If the
-              *Pixel Data* is compressed then a :doc:`suitable pixel data
-              handler </old/image_data_handlers>` must be available to
-              decompress it.
+              the uncompressed *Pixel Data* to be encoded.
             * :class:`bytes`: the uncompressed little-endian ordered pixel
               data. Using ``bytes`` as the `src` will bypass some of the
               validation checks and is only recommended for advanced users.
@@ -349,10 +346,7 @@ class Encoder:
                 multi-sample data.
 
             * :class:`~pydicom.dataset.Dataset`: the dataset containing
-              the compressed or uncompressed *Pixel Data* to be encoded. If the
-              *Pixel Data* is compressed then a :doc:`suitable pixel data
-              handler </old/image_data_handlers>` must be available to
-              decompress it.
+              the uncompressed *Pixel Data* to be encoded.
             * :class:`bytes`: the uncompressed little-endian ordered pixel
               data. Using ``bytes`` as the `src` will bypass some of the
               validation checks and is only recommended for advanced users.
