@@ -9,6 +9,7 @@ import sys
 import weakref
 
 import pytest
+from pydicom.tests.test_helpers import assert_no_warning
 
 try:
     import numpy
@@ -34,7 +35,9 @@ from pydicom.uid import (
     ImplicitVRLittleEndian,
     ExplicitVRBigEndian,
     JPEGBaseline8Bit,
-    PYDICOM_IMPLEMENTATION_UID
+    PYDICOM_IMPLEMENTATION_UID,
+    ExplicitVRLittleEndian,
+    MediaStorageDirectoryStorage
 )
 from pydicom.valuerep import DS
 
@@ -47,7 +50,7 @@ class BadRepr:
 class TestDataset:
     """Tests for dataset.Dataset."""
 
-    def setup(self):
+    def setup_method(self):
         self.ds = Dataset()
         self.ds.TreatmentMachineName = "unit001"
 
@@ -247,9 +250,8 @@ class TestDataset:
 
     def test_contains_ignore(self, contains_ignore):
         """Test ignoring invalid keys."""
-        with pytest.warns(None) as record:
+        with assert_no_warning():
             assert 'invalid' not in self.ds
-            assert len(record) == 0
 
     def test_clear(self):
         assert 1 == len(self.ds)
@@ -1245,6 +1247,21 @@ class TestDataset:
         assert ds[tag2].value == b'\x03\x04'
         assert ds[tag2].VR == 'UN'
 
+    def test_invalid_private_creator(self):
+        # regression test for #1638
+        ds = Dataset()
+        ds.add_new(0x00250010, "SL", [13975, 13802])
+        ds.add_new(0x00250011, "LO", "Valid Creator")
+        ds.add_new(0x00251007, "UN", "foobar")
+        ds.add_new(0x00251107, "UN", "foobaz")
+        msg = (r"\(0025, 0010\) '\[13975, 13802]' "
+               r"is not a valid private creator")
+        with pytest.warns(UserWarning, match=msg):
+            assert (str(ds[0x00251007]) == "(0025, 1007) Private tag data"
+                                           "                    UN: 'foobar'")
+        assert (str(ds[0x00251107]) == "(0025, 1107) Private tag data"
+                                       "                    UN: 'foobaz'")
+
     def test_is_original_encoding(self):
         """Test Dataset.write_like_original"""
         ds = Dataset()
@@ -1495,6 +1512,20 @@ class TestDataset:
         with dcmread(test_file) as ds:
             assert 'CompressedSamples^CT1' == ds.PatientName
 
+    def test_invalid_dicomdir_handled_as_filedataset(self):
+        ds = Dataset()
+        ds.file_meta = FileMetaDataset()
+        ds.file_meta.TransferSyntaxUID = ExplicitVRLittleEndian
+        ds.file_meta.MediaStorageSOPClassUID = MediaStorageDirectoryStorage
+        ds.PatientName = "Doe^John"
+        fp = DicomBytesIO()
+        ds.save_as(fp)
+        msg = ("The SOP Class 'Media Storage Directory Storage' does"
+               "not match the contents of the dataset*")
+        with pytest.warns(UserWarning, match=msg):
+            ds = dcmread(fp, force=True)
+        assert ds.PatientName == "Doe^John"
+
     def test_exit_exception(self):
         """Test Dataset.__exit__ when an exception is raised."""
 
@@ -1669,7 +1700,7 @@ class TestDataset:
 class TestDatasetElements:
     """Test valid assignments of data elements"""
 
-    def setup(self):
+    def setup_method(self):
         self.ds = Dataset()
         self.sub_ds1 = Dataset()
         self.sub_ds2 = Dataset()
@@ -1779,7 +1810,7 @@ class TestDatasetElements:
 
 
 class TestFileDataset:
-    def setup(self):
+    def setup_method(self):
         self.test_file = get_testdata_file('CT_small.dcm')
 
     def test_pickle_raw_data(self):
@@ -1791,13 +1822,13 @@ class TestFileDataset:
 
     def test_pickle_data_elements(self):
         ds = pydicom.dcmread(self.test_file)
-        assert ds.OtherPatientIDsSequence.parent == weakref.ref(ds)
+        assert ds.OtherPatientIDsSequence.parent_dataset == weakref.ref(ds)
         for e in ds:
             # make sure all data elements have been loaded
             pass
         s = pickle.dumps({'ds': ds})
         ds1 = pickle.loads(s)['ds']
-        assert ds1.OtherPatientIDsSequence.parent == weakref.ref(ds)
+        assert ds1.OtherPatientIDsSequence.parent_dataset == weakref.ref(ds)
         assert ds == ds1
 
     def test_pickle_nested_sequence(self):
@@ -1940,11 +1971,21 @@ class TestFileDataset:
         ds2 = copy.deepcopy(ds)
         assert ds2.filename == ""
 
+    def test_deepcopy_dataset_subclass(self):
+        """Regression test for #1813."""
+        class MyDatasetSubclass(pydicom.Dataset):
+            pass
+
+        my_dataset_subclass = MyDatasetSubclass()
+
+        ds2 = copy.deepcopy(my_dataset_subclass)
+        assert ds2.__class__ is MyDatasetSubclass
+
 
 class TestDatasetOverlayArray:
     """Tests for Dataset.overlay_array()."""
 
-    def setup(self):
+    def setup_method(self):
         """Setup the test datasets and the environment."""
         self.original_handlers = pydicom.config.overlay_data_handlers
         pydicom.config.overlay_data_handlers = [NP_HANDLER]
@@ -1976,7 +2017,7 @@ class TestDatasetOverlayArray:
 
         self.dummy = DummyHandler()
 
-    def teardown(self):
+    def teardown_method(self):
         """Restore the environment."""
         pydicom.config.overlay_data_handlers = self.original_handlers
 
@@ -2129,6 +2170,12 @@ class TestFileMeta:
         assert ds_copy.BeamSequence[1].Manufacturer == "Linac and Sons, co."
         if copy_method == copy.deepcopy:
             assert id(ds_copy.BeamSequence[0]) != id(ds.BeamSequence[0])
+
+            # dereference weakrefs and check are pointing to correct objects
+            assert ds.BeamSequence is ds.BeamSequence[0].parent_seq()
+            assert ds is ds.BeamSequence.parent_dataset()
+            assert ds_copy.BeamSequence is ds_copy.BeamSequence[0].parent_seq()
+            assert ds_copy is ds_copy.BeamSequence.parent_dataset()
         else:
             # shallow copy
             assert id(ds_copy.BeamSequence[0]) == id(ds.BeamSequence[0])
@@ -2162,6 +2209,8 @@ def contains_warn():
     config.INVALID_KEY_BEHAVIOR = "WARN"
     yield
     config.INVALID_KEY_BEHAVIOR = original
+
+
 CAMEL_CASE = (
     [  # Shouldn't warn
         "Rows", "_Rows", "Rows_", "rows", "_rows", "__rows", "rows_", "ro_ws",
@@ -2170,7 +2219,7 @@ CAMEL_CASE = (
         "12LeadECG", "file_meta", "filename", "is_implicit_VR",
         "is_little_endian", "preamble", "timestamp", "fileobj_type",
         "patient_records", "_parent_encoding", "_dict", "is_decompressed",
-        "read_little_endian", "read_implicit_vr", "read_encoding", "parent",
+        "read_little_endian", "read_implicit_vr", "read_encoding",
         "_private_blocks", "default_element_format", "indent_chars",
         "default_sequence_element_format", "PatientName"
     ],
@@ -2210,15 +2259,13 @@ def setattr_warn():
 
 def test_setattr_warns(setattr_warn):
     """"Test warnings for Dataset.__setattr__() for close matches."""
-    with pytest.warns(None) as record:
+    with assert_no_warning():
         ds = Dataset()
-        assert len(record) == 0
 
     for s in CAMEL_CASE[0]:
-        with pytest.warns(None) as record:
+        with assert_no_warning():
             val = getattr(ds, s, None)
             setattr(ds, s, val)
-            assert len(record) == 0
 
     for s in CAMEL_CASE[1]:
         msg = (
@@ -2232,15 +2279,13 @@ def test_setattr_warns(setattr_warn):
 
 def test_setattr_raises(setattr_raise):
     """"Test exceptions for Dataset.__setattr__() for close matches."""
-    with pytest.warns(None) as record:
+    with assert_no_warning():
         ds = Dataset()
-        assert len(record) == 0
 
     for s in CAMEL_CASE[0]:
-        with pytest.warns(None) as record:
+        with assert_no_warning():
             val = getattr(ds, s, None)
             setattr(ds, s, val)
-            assert len(record) == 0
 
     for s in CAMEL_CASE[1]:
         msg = (
@@ -2254,19 +2299,16 @@ def test_setattr_raises(setattr_raise):
 
 def test_setattr_ignore(setattr_ignore):
     """Test config.INVALID_KEYWORD_BEHAVIOR = 'IGNORE'"""
-    with pytest.warns(None) as record:
+    with assert_no_warning():
         ds = Dataset()
-        assert len(record) == 0
 
     for s in CAMEL_CASE[0]:
-        with pytest.warns(None) as record:
+        with assert_no_warning():
             val = getattr(ds, s, None)
             setattr(ds, s, val)
-            assert len(record) == 0
 
     ds = Dataset()
     for s in CAMEL_CASE[1]:
-        with pytest.warns(None) as record:
-            val = getattr(ds, s, None)
+        with assert_no_warning():
+            getattr(ds, s, None)
             setattr(ds, s, None)
-            assert len(record) == 0
