@@ -1,6 +1,5 @@
 # Copyright 2008-2020 pydicom authors. See LICENSE file for details.
 """Test suite for util functions"""
-import sys
 from io import BytesIO
 from pathlib import Path
 
@@ -31,7 +30,5 @@ class TestPathFromPathLike:
     def test_pathlib_path(self):
         assert 'test.dcm' == path_from_pathlike(Path('test.dcm'))
 
-    @pytest.mark.skipif(sys.version_info < (3, 6),
-                        reason="Path-like objects introduced in Python 3.6")
     def test_path_like(self):
         assert 'test.dcm' == path_from_pathlike(PathLike('test.dcm'))
