@@ -7,6 +7,7 @@ from struct import unpack, pack
 from sys import byteorder
 
 import pytest
+from pydicom.tests.test_helpers import assert_no_warning
 
 try:
     import numpy as np
@@ -105,7 +106,7 @@ REFERENCE_DTYPE = [
 @pytest.mark.skipif(not HAVE_NP, reason="Numpy is not available")
 class TestNumpy_PixelDtype:
     """Tests for util.pixel_dtype."""
-    def setup(self):
+    def setup_method(self):
         """Setup the test dataset."""
         self.ds = Dataset()
         self.ds.file_meta = FileMetaDataset()
@@ -114,7 +115,8 @@ class TestNumpy_PixelDtype:
     def test_unknown_pixel_representation_raises(self):
         """Test an unknown PixelRepresentation value raises exception."""
         self.ds.BitsAllocated = 16
-        self.ds.PixelRepresentation = -1
+        with pytest.warns(UserWarning):
+            self.ds.PixelRepresentation = -1
         # The bracket needs to be escaped
         with pytest.raises(ValueError,
                            match=r"value of '-1' for '\(0028,0103"):
@@ -292,7 +294,7 @@ if HAVE_NP:
 @pytest.mark.skipif(not HAVE_NP, reason="Numpy is not available")
 class TestNumpy_ReshapePixelArray:
     """Tests for util.reshape_pixel_array."""
-    def setup(self):
+    def setup_method(self):
         """Setup the test dataset."""
         self.ds = Dataset()
         self.ds.file_meta = FileMetaDataset()
@@ -938,12 +940,12 @@ class TestNumpy_ModalityLUT:
 @pytest.mark.skipif(not HAVE_NP, reason="Numpy is not available")
 class TestNumpy_PaletteColor:
     """Tests for util.apply_color_lut()."""
-    def setup(self):
+    def setup_method(self):
         """Setup the tests"""
         self.o_palette = get_palette_files('pet.dcm')[0]
         self.n_palette = get_palette_files('pet.dcm')[0][:-3] + 'tmp'
 
-    def teardown(self):
+    def teardown_method(self):
         """Teardown the tests"""
         if os.path.exists(self.n_palette):
             os.rename(self.n_palette, self.o_palette)
@@ -1207,10 +1209,11 @@ class TestNumpy_PaletteColor:
         assert ([50944, 16384, 27904] == rgb[arr == 149]).all()
 
     def test_first_map_negative(self):
-        """Test a positive first mapping value."""
+        """Test a negative first mapping value."""
         ds = dcmread(PAL_08_200_0_16_1F, force=True)
         ds.file_meta = FileMetaDataset()
         ds.file_meta.TransferSyntaxUID = ImplicitVRLittleEndian
+        ds["RedPaletteColorLookupTableDescriptor"].VR = "SS"
         ds.RedPaletteColorLookupTableDescriptor[1] = -10
         arr = ds.pixel_array
         rgb = apply_color_lut(arr, ds)
@@ -2234,17 +2237,15 @@ class TestGetNrFrames:
         """Test return value when (0028,0008) 'Number of Frames' does not
             exist"""
         ds = Dataset()
-        with pytest.warns(None) as w:
+        with assert_no_warning():
             assert 1 == get_nr_frames(ds)
-            assert not w
 
     def test_existing(self):
         """Test return value when (0028,0008) 'Number of Frames' exists."""
         ds = Dataset()
         ds.NumberOfFrames = random.randint(1, 10)
-        with pytest.warns(None) as w:
+        with assert_no_warning():
             assert ds.NumberOfFrames == get_nr_frames(ds)
-            assert not w
 
 
 REFERENCE_PACK_UNPACK = [
