@@ -2,9 +2,10 @@
 """Unit tests for the pydicom.multival module."""
 
 import pytest
+
+from pydicom import config
 from pydicom.multival import MultiValue
 from pydicom.valuerep import DS, DSfloat, DSdecimal, IS
-from pydicom import config
 from copy import deepcopy
 
 import sys
@@ -35,10 +36,11 @@ class TestMultiValue:
         assert not multival
         assert 0 == len(multival)
 
-    def testLimits(self, enforce_valid_values):
+    def testLimits(self):
         """MultiValue: Raise error if any item outside DICOM limits...."""
         with pytest.raises(OverflowError):
-            MultiValue(IS, [1, -2 ** 31 - 1])
+            MultiValue(IS, [1, -2 ** 31 - 1],
+                       validation_mode=config.RAISE)
         # Overflow error not raised for IS out of DICOM valid range
 
     def testAppend(self):
