@@ -1,6 +1,7 @@
 # Copyright 2008-2020 pydicom authors. See LICENSE file for details.
 """Unit tests for the pydicom.sequence module."""
 
+import copy
 import weakref
 
 import pytest
@@ -87,14 +88,14 @@ class TestSequence:
         parent.PatientName = "Parent"
 
         seq = Sequence()
-        seq.parent = parent
-        assert isinstance(seq.parent, weakref.ReferenceType)
+        seq.parent_dataset = parent
+        assert isinstance(seq.parent_dataset, weakref.ReferenceType)
         seq.append(ds_a)
         seq.append(ds_c)
         seq.insert(1, ds_b)
         assert 3 == len(seq)
         for ds in seq:
-            assert isinstance(ds.parent, weakref.ReferenceType)
+            assert isinstance(ds.parent_seq, weakref.ReferenceType)
 
         seq[1] = ds_e
         assert ds_e == seq[1]
@@ -104,7 +105,7 @@ class TestSequence:
         seq[1:2] = [ds_c, ds_e]
         assert [ds_a, ds_c, ds_e, ds_e, ds_c] == seq
         for ds in seq:
-            assert isinstance(ds.parent, weakref.ReferenceType)
+            assert isinstance(ds.parent_seq, weakref.ReferenceType)
 
         msg = r"Can only assign an iterable of 'Dataset'"
         with pytest.raises(TypeError, match=msg):
@@ -127,8 +128,8 @@ class TestSequence:
         parent.PatientName = "Parent"
 
         seq = Sequence()
-        seq.parent = parent
-        assert isinstance(seq.parent, weakref.ReferenceType)
+        seq.parent_dataset = parent
+        assert isinstance(seq.parent_dataset, weakref.ReferenceType)
         seq.extend([ds_a, ds_b, ds_c])
         assert [ds_a, ds_b, ds_c] == seq
 
@@ -140,7 +141,7 @@ class TestSequence:
         seq.extend([ds_d, ds_e])
         assert [ds_a, ds_b, ds_c, ds_d, ds_e] == seq
         for ds in seq:
-            assert isinstance(ds.parent, weakref.ReferenceType)
+            assert isinstance(ds.parent_seq, weakref.ReferenceType)
 
     def test_iadd(self):
         """Test Sequence() += [Dataset()]."""
@@ -159,8 +160,8 @@ class TestSequence:
         parent.PatientName = "Parent"
 
         seq = Sequence()
-        seq.parent = parent
-        assert isinstance(seq.parent, weakref.ReferenceType)
+        seq.parent_dataset = parent
+        assert isinstance(seq.parent_dataset, weakref.ReferenceType)
         seq += [ds_a, ds_b, ds_c]
         assert [ds_a, ds_b, ds_c] == seq
 
@@ -173,4 +174,14 @@ class TestSequence:
         assert [ds_a, ds_b, ds_c, ds_d, ds_e] == seq
 
         for ds in seq:
-            assert isinstance(ds.parent, weakref.ReferenceType)
+            assert isinstance(ds.parent_seq, weakref.ReferenceType)
+
+    def test_deepcopy_sequence_subclass(self):
+        """Regression test for #1813."""
+        class MySequenceSubclass(Sequence):
+            pass
+
+        my_sequence_subclass = MySequenceSubclass()
+
+        seq2 = copy.deepcopy(my_sequence_subclass)
+        assert seq2.__class__ is MySequenceSubclass
