@@ -205,6 +205,13 @@ class TestBaseTag:
         assert '(1000, 2000)' == str(BaseTag(0x10002000))
         assert '(ffff, fffe)' == str(BaseTag(0xFFFFFFFE))
 
+    def test_json_key(self):
+        """Test BaseTag.json_key() produces correct value."""
+        assert '00000000' == BaseTag(0x00000000).json_key
+        assert '00010002' == BaseTag(0x00010002).json_key
+        assert '10002000' == BaseTag(0x10002000).json_key
+        assert 'FFFFFFFE' == BaseTag(0xFFFFFFFE).json_key
+
     def test_group(self):
         """Test BaseTag.group returns correct values."""
         assert 0x0000 == BaseTag(0x00000001).group
@@ -226,7 +233,7 @@ class TestBaseTag:
         # Group 0 not private
         assert not BaseTag(0x00000001).is_private
 
-    def test_private_creator(self):
+    def test_is_private_creator(self):
         """Test BaseTag.is_private_creator returns correct values."""
         # Non-private tag
         assert not BaseTag(0x00080010).is_private_creator
@@ -236,6 +243,10 @@ class TestBaseTag:
         assert BaseTag(0x000900FF).is_private_creator
         assert not BaseTag(0x00090100).is_private_creator
 
+    def test_private_creator(self):
+        assert BaseTag(0x00091000).private_creator == BaseTag(0x00090010)
+        assert BaseTag(0x00292526).private_creator == BaseTag(0x00290025)
+
 
 class TestTag:
     """Test the Tag method."""
