@@ -6,6 +6,7 @@ import copy
 from datetime import datetime, date, time, timedelta, timezone
 from decimal import Decimal
 from itertools import chain
+from io import BytesIO
 import pickle
 import math
 import sys
@@ -19,9 +20,10 @@ from pydicom.config import settings
 from pydicom.data import get_testdata_file
 from pydicom.dataset import Dataset
 from pydicom._dicom_dict import DicomDictionary, RepeatersDictionary
+from pydicom.filereader import read_dataset
 from pydicom.tag import Tag
 from pydicom.valuerep import (
-    DS, IS, DSfloat, DSdecimal, PersonName, VR, STANDARD_VR,
+    DS, IS, DSfloat, DSdecimal, ISfloat, PersonName, VR, STANDARD_VR,
     AMBIGUOUS_VR, STR_VR, BYTES_VR, FLOAT_VR, INT_VR, LIST_VR
 )
 from pydicom.values import convert_value
@@ -603,6 +605,13 @@ class TestDSfloat:
             valuerep.DSfloat('3.141592653589793',
                              validation_mode=config.RAISE)
 
+    def test_handle_missing_leading_zero(self):
+        """Test that no error is raised with maximum length DS string
+        without leading zero."""
+        # Regression test for #1632
+        valuerep.DSfloat(".002006091181818",
+                         validation_mode=config.RAISE)
+
     def test_DSfloat_auto_format(self):
         """Test creating a value using DSfloat copies auto_format"""
         x = DSfloat(math.pi, auto_format=True)
@@ -882,11 +891,31 @@ class TestIS:
         assert 42 == IS("42.0")
         assert 42 == IS(42.0)
 
+    def test_float_value(self):
+        """Read binary value of IS that is actually a float"""
+        # from issue #1661
+        # Create BytesIO with single data element for Exposure (0018,1152)
+        #   length 4, value "14.5"
+        bin_elem = b"\x18\x00\x52\x11\x04\x00\x00\x0014.5"
+        with BytesIO(bin_elem) as bio:
+            ds = read_dataset(bio, True, True)
+        assert isinstance(ds.Exposure, ISfloat)
+        assert ds.Exposure == 14.5
+
+        # Strict checking raises an error
+        with pytest.raises(ValueError):
+            _ = IS("14.5", validation_mode=config.RAISE)
+        with pytest.raises(TypeError):
+            _ = IS(14.5, validation_mode=config.RAISE)
+
+    def test_float_init(self):
+        """New ISfloat created from another behaves correctly"""
+        is1 = IS("14.5", validation_mode=config.IGNORE)
+        is2 = IS(is1)
+        assert is1 == is2
+        assert is2.original_string == is1.original_string
+
     def test_invalid_value(self, disable_value_validation):
-        with pytest.raises(TypeError, match="Could not convert value"):
-            IS(0.9)
-        with pytest.raises(TypeError, match="Could not convert value"):
-            IS("0.9")
         with pytest.raises(ValueError, match="could not convert string"):
             IS("foo")
 
@@ -984,7 +1013,7 @@ class TestIS:
 class TestBadValueRead:
     """Unit tests for handling a bad value for a VR
        (a string in a number VR here)"""
-    def setup(self):
+    def setup_method(self):
         class TagLike:
             pass
 
@@ -996,7 +1025,7 @@ class TestBadValueRead:
         self.tag.length = 2
         self.default_retry_order = pydicom.values.convert_retry_VR_order
 
-    def teardown(self):
+    def teardown_method(self):
         pydicom.values.convert_retry_VR_order = self.default_retry_order
 
     def test_read_bad_value_in_VR_default(self, disable_value_validation):
@@ -1051,12 +1080,19 @@ class TestDecimalString:
 class TestPersonName:
     def test_last_first(self):
         """PN: Simple Family-name^Given-name works..."""
-        pn = PersonName("Family^Given")
+        value = "Family^Given"
+        pn = PersonName(val=value)
+        assert value == pn.alphabetic
         assert "Family" == pn.family_name
         assert "Given" == pn.given_name
         assert "" == pn.name_suffix
         assert "" == pn.phonetic
 
+    def test_no_components(self):
+        """PN: Empty Person Name does not raise errors..."""
+        pn = PersonName(val="")
+        assert "" == pn.alphabetic == pn.phonetic == pn.ideographic
+
     def test_copy(self):
         """PN: Copy and deepcopy works..."""
         pn = PersonName(
@@ -1084,11 +1120,15 @@ class TestPersonName:
         phonetic characters) works..."""
         # Example name from PS3.5-2008 section I.2 p. 108
         pn = PersonName(
-            "Hong^Gildong="
+            "Hong^Gildong^Andrews="
             "\033$)C\373\363^\033$)C\321\316\324\327="
             "\033$)C\310\253^\033$)C\261\346\265\277"
         )
-        assert ("Hong", "Gildong") == (pn.family_name, pn.given_name)
+        assert ("Hong", "Gildong", "Andrews") == \
+               (pn.family_name, pn.given_name, pn.middle_name)
+        assert "Hong^Gildong^Andrews" == pn.alphabetic
+        assert "\033$)C\373\363^\033$)C\321\316\324\327" == pn.ideographic
+        assert "\033$)C\310\253^\033$)C\261\346\265\277" == pn.phonetic
 
     def test_formatting(self):
         """PN: Formatting works..."""
@@ -1385,10 +1425,10 @@ class TestPersonName:
 
 class TestDateTime:
     """Unit tests for DA, DT, TM conversion to datetime objects"""
-    def setup(self):
+    def setup_method(self):
         config.datetime_conversion = True
 
-    def teardown(self):
+    def teardown_method(self):
         config.datetime_conversion = False
 
     def test_date(self):
