@@ -77,14 +77,39 @@ BYTE_VR_REGEXES = {vr: re.compile(regex.encode())
                    for (vr, regex) in VR_REGEXES.items()}
 
 
-def validate_vr_length(vr: str, value: Union[str, bytes]) -> Tuple[bool, str]:
+def validate_type(vr: str, value: Any,
+                  types: Union[Type, Tuple[Type, Type]]) -> Tuple[bool, str]:
+    """Checks for valid types for a given VR.
+
+    Parameters
+    ----------
+    vr : str
+        The value representation to validate against.
+    value : Any
+        The value to validate.
+    types: Type or Tuple[Type]
+        The type or tuple of types supported for the given VR.
+
+    Returns
+    -------
+        A tuple of a boolean validation result and the error message.
+    """
+    if value is not None and not isinstance(value, types):
+        return False, (
+            f"A value of type '{type(value).__name__}' cannot be "
+            f"assigned to a tag with VR {vr}."
+        )
+    return True, ""
+
+
+def validate_vr_length(vr: str, value: Any) -> Tuple[bool, str]:
     """Validate the value length for a given VR.
 
     Parameters
     ----------
     vr : str
         The value representation to validate against.
-    value : str or bytes
+    value : Any
         The value to validate.
 
     Returns
@@ -102,7 +127,27 @@ def validate_vr_length(vr: str, value: Union[str, bytes]) -> Tuple[bool, str]:
     return True, ""
 
 
-def validate_regex(vr: str, value: Union[str, bytes]) -> Tuple[bool, str]:
+def validate_type_and_length(vr: str, value: Any) -> Tuple[bool, str]:
+    """Validate the correct type and the value length for a given VR.
+
+    Parameters
+    ----------
+    vr : str
+        The value representation to validate against.
+    value : Any
+        The value to validate.
+
+    Returns
+    -------
+        A tuple of a boolean validation result and the error message.
+    """
+    valid, msg = validate_type(vr, value, (str, bytes))
+    if not valid:
+        return valid, msg
+    return validate_vr_length(vr, value)
+
+
+def validate_regex(vr: str, value: Any) -> Tuple[bool, str]:
     """Validate the value for a given VR for allowed characters
     using a regular expression.
 
@@ -110,7 +155,7 @@ def validate_regex(vr: str, value: Union[str, bytes]) -> Tuple[bool, str]:
     ----------
     vr : str
         The value representation to validate against.
-    value : str
+    value : Any
         The value to validate.
 
     Returns
@@ -131,22 +176,69 @@ def validate_regex(vr: str, value: Union[str, bytes]) -> Tuple[bool, str]:
     return True, ""
 
 
-def validate_length_and_regex(
-        vr: str, value: Union[str, bytes]) -> Tuple[bool, str]:
-    """Validate the value for a given VR both for maximum length and
-    for allowed characters using a regular expression.
+def validate_type_and_regex(vr: str, value: Any) -> Tuple[bool, str]:
+    """Validate that the value is of type :class:`str` or :class:`bytes`
+    and that the value matches the VR-specific regular expression.
 
     Parameters
     ----------
     vr : str
         The value representation to validate against.
-    value : str
+    value : Any
         The value to validate.
 
     Returns
     -------
         A tuple of a boolean validation result and the error message.
     """
+    valid, msg = validate_type(vr, value, (str, bytes))
+    if not valid:
+        return valid, msg
+    return validate_regex(vr, value)
+
+
+def validate_date_time(
+        vr: str, value: Any, date_time_type: Type) -> Tuple[bool, str]:
+    """Checks for valid values for date/time related VRs.
+
+    Parameters
+    ----------
+    vr : str
+        The value representation to validate against.
+    value : Any
+        The value to validate.
+    date_time_type: type
+        The specific type supported for the given VR (additional to str/bytes).
+
+    Returns
+    -------
+        A tuple of a boolean validation result and the error message.
+    """
+
+    if value and isinstance(value, date_time_type):
+        return True, ""
+    return validate_type_and_regex(vr, value)
+
+
+def validate_length_and_type_and_regex(
+        vr: str, value: Any) -> Tuple[bool, str]:
+    """Validate the value for a given VR for maximum length, for the correct
+    value type, and for allowed characters using a regular expression.
+
+    Parameters
+    ----------
+    vr : str
+        The value representation to validate against.
+    value : Any
+        The value to validate.
+
+    Returns
+    -------
+        A tuple of a boolean validation result and the error message.
+    """
+    valid, msg = validate_type(vr, value, (str, bytes))
+    if not valid:
+        return valid, msg
     is_valid_len, msg1 = validate_vr_length(vr, value)
     is_valid_expr, msg2 = validate_regex(vr, value)
     msg = " ".join([msg1, msg2]).strip()
@@ -158,8 +250,7 @@ def validate_length_and_regex(
     return is_valid_len and is_valid_expr, msg
 
 
-def validate_pn_component_length(
-        vr: str, value: Union[str, bytes]) -> Tuple[bool, str]:
+def validate_pn_component_length(vr: str, value: Any) -> Tuple[bool, str]:
     """Validate the PN component value for the maximum length.
 
     Parameters
@@ -181,7 +272,7 @@ def validate_pn_component_length(
     return True, ""
 
 
-def validate_pn(vr: str, value: Union[str, bytes]) -> Tuple[bool, str]:
+def validate_pn(vr: str, value: Any) -> Tuple[bool, str]:
     """Validate the value for VR PN for the maximum number of components
     and for the maximum length of each component.
 
@@ -196,8 +287,11 @@ def validate_pn(vr: str, value: Union[str, bytes]) -> Tuple[bool, str]:
     -------
         A tuple of a boolean validation result and the error message.
     """
-    if not value:
+    if not value or isinstance(value, PersonName):
         return True, ""
+    valid, msg = validate_type(vr, value, (str, bytes))
+    if not valid:
+        return valid, msg
     components: Sequence[Union[str, bytes]]
     if isinstance(value, bytes):
         components = value.split(b"=")
@@ -233,22 +327,81 @@ def validate_pn_component(value: Union[str, bytes]) -> None:
                    validate_pn_component_length)
 
 
+VALUE_LENGTH = {
+    "US": 2,
+    "SS": 2,
+    "UL": 4,
+    "SL": 4,
+    "UV": 8,
+    "SV": 8,
+    "FL": 4,
+    "FD": 8
+}
+
+
+def validate_number(
+        vr: str, value: Any, min_value: int, max_value: int
+) -> Tuple[bool, str]:
+    """Validate the value for a numerical VR for type and allowed range.
+
+    Parameters
+    ----------
+    vr : str
+        The value representation to validate against.
+    value : Any
+        The value to validate.
+    min_value : int
+        The minimum allowed value.
+    max_value : int
+        The maximum allowed value.
+
+    Returns
+    -------
+        A tuple of a boolean validation result and the error message.
+    """
+    valid, msg = validate_type(vr, value, (int, bytes))
+    if not valid:
+        return valid, msg
+    if isinstance(value, int):
+        if value < min_value or value > max_value:
+            return False, (
+                f"Invalid value: a value for a tag with VR {vr} must be "
+                f"between {min_value} and {max_value}."
+            )
+    elif len(value) % VALUE_LENGTH[vr]:
+        return False, (
+            f"Invalid value length {len(value)}: the value length for a tag "
+            f"with VR {vr} must be a multiple of {VALUE_LENGTH[vr]}."
+        )
+    return True, ""
+
+
 VALIDATORS = {
-    "AE": validate_length_and_regex,
-    "AS": validate_regex,
-    "CS": validate_length_and_regex,
-    "DA": validate_regex,
-    "DS": validate_length_and_regex,
-    "DT": validate_regex,
-    "IS": validate_length_and_regex,
-    "LO": validate_vr_length,
-    "LT": validate_vr_length,
+    "AE": validate_length_and_type_and_regex,
+    "AS": validate_type_and_regex,
+    "CS": validate_length_and_type_and_regex,
+    "DA": lambda vr, value: validate_date_time(vr, value, datetime.date),
+    "DS": validate_length_and_type_and_regex,
+    "DT": lambda vr, value: validate_date_time(vr, value, datetime.datetime),
+    "FD": lambda vr, value: validate_type(vr, value, (float, int)),
+    "FL": lambda vr, value: validate_type(vr, value, (float, int)),
+    "IS": validate_length_and_type_and_regex,
+    "LO": validate_type_and_length,
+    "LT": validate_type_and_length,
     "PN": validate_pn,
-    "SH": validate_vr_length,
-    "ST": validate_vr_length,
-    "TM": validate_regex,
-    "UI": validate_length_and_regex,
-    "UR": validate_regex,
+    "SH": validate_type_and_length,
+    "SL": lambda vr, value: validate_number(
+        vr, value, -0x80000000, 0x7fffffff),
+    "SS": lambda vr, value: validate_number(vr, value, -0x8000, 0x7fff),
+    "ST": validate_type_and_length,
+    "SV": lambda vr, value: validate_number(
+        vr, value, -0x8000000000000000, 0x7fffffffffffffff),
+    "TM": lambda vr, value: validate_date_time(vr, value, datetime.time),
+    "UI": validate_length_and_type_and_regex,
+    "UL": lambda vr, value: validate_number(vr, value, 0, 0xffffffff),
+    "US": lambda vr, value: validate_number(vr, value, 0, 0xffff),
+    "UR": validate_type_and_regex,
+    "UV": lambda vr, value: validate_number(vr, value, 0, 0xffffffffffffffff),
 }
 
 
@@ -280,7 +433,7 @@ def validate_value(vr: str, value: Any,
     if validation_mode == config.IGNORE:
         return
 
-    if value is not None and isinstance(value, (str, bytes)):
+    if value is not None:
         validator = validator or VALIDATORS.get(vr)
         if validator is not None:
             is_valid, msg = validator(vr, value)
@@ -721,7 +874,7 @@ def is_valid_ds(s: str) -> bool:
     bool
         True if the string is a valid decimal string. Otherwise False.
     """
-    return validate_length_and_regex("DS", s)[0]
+    return validate_length_and_type_and_regex("DS", s)[0]
 
 
 def format_number_as_ds(val: Union[float, Decimal]) -> str:
@@ -874,7 +1027,7 @@ class DSfloat(float):
 
         if (validation_mode == config.RAISE and
                 not self.auto_format):
-            if len(repr(self)[1:-1]) > 16:
+            if len(str(self)) > 16:
                 raise OverflowError(
                     "Values for elements with a VR of 'DS' must be <= 16 "
                     "characters long, but the float provided requires > 16 "
@@ -884,7 +1037,7 @@ class DSfloat(float):
                     "explicitly construct a DS object with 'auto_format' "
                     "set to True"
                 )
-            if not is_valid_ds(repr(self)[1:-1]):
+            if not is_valid_ds(str(self)):
                 # This will catch nan and inf
                 raise ValueError(
                     f'Value "{str(self)}" is not valid for elements with a VR '
@@ -1095,6 +1248,49 @@ def DS(
     return DSfloat(val, auto_format, validation_mode)
 
 
+class ISfloat(float):
+    """Store value for an element with VR **IS** as :class:`float`.
+
+    Stores original integer string for exact rewriting of the string
+    originally read or stored.
+
+    Note: By the DICOM standard, IS can only be an :class:`int`,
+    however, it is not uncommon to see float IS values.  This class
+    is used if the config settings allow non-strict reading.
+
+    Generally, use :class:`~pydicom.valuerep.IS` to create IS values,
+    this is returned instead if the value cannot be represented as an
+    :class:`int`.  See :class:`~pydicom.valuerep.IS` for details of the
+    parameters and return values.
+    """
+    def __new__(  # type: ignore[misc]
+            cls: Type["ISfloat"], val: Union[str, float, Decimal],
+            validation_mode: int = None
+    ) -> float:
+        return super().__new__(cls, val)
+
+    def __init__(self, val: Union[str, float, Decimal],
+                 validation_mode: int = None) -> None:
+        # If a string passed, then store it
+        if isinstance(val, str):
+            self.original_string = val.strip()
+        elif (isinstance(val, (IS, ISfloat))
+                and hasattr(val, 'original_string')):
+            self.original_string = val.original_string
+        if validation_mode:
+            msg = (
+                f'Value "{str(self)}" is not valid for elements with a VR '
+                'of IS'
+            )
+            if validation_mode == config.WARN:
+                warnings.warn(msg)
+            elif validation_mode == config.RAISE:
+                msg += (
+                    "\nSet reading_validation_mode to WARN or IGNORE to bypass"
+                )
+                raise TypeError(msg)
+
+
 class IS(int):
     """Store value for an element with VR **IS** as :class:`int`.
 
@@ -1105,7 +1301,7 @@ class IS(int):
     def __new__(  # type: ignore[misc]
             cls: Type["IS"], val: Union[None, str, int, float, Decimal],
             validation_mode: int = None
-    ) -> Optional[Union[str, "IS"]]:
+    ) -> Optional[Union[str, "IS", "ISfloat"]]:
         """Create instance if new integer string"""
         if val is None:
             return val
@@ -1119,16 +1315,16 @@ class IS(int):
             validate_value("IS", val, validation_mode)
 
         try:
-            newval = super().__new__(cls, val)
+            newval: Union[IS, ISfloat] = super().__new__(cls, val)
         except ValueError:
             # accept float strings when no integer loss, e.g. "1.0"
             newval = super().__new__(cls, float(val))
 
-        # check if a float or Decimal passed in, then could have lost info,
-        # and will raise error. E.g. IS(Decimal('1')) is ok, but not IS(1.23)
-        #   IS('1.23') will raise ValueError
+        # If a float or Decimal was passed in, check for non-integer,
+        # i.e. could lose info if converted to int
+        # If so, create an ISfloat instead (if allowed by settings)
         if isinstance(val, (float, Decimal, str)) and newval != float(val):
-            raise TypeError("Could not convert value to integer without loss")
+            newval = ISfloat(val, validation_mode)
 
         # Checks in case underlying int is >32 bits, DICOM does not allow this
         if (not -2**31 <= newval < 2**31 and
@@ -1287,7 +1483,6 @@ def _encode_personname(
             encode_string(group, encodings) for group in comp.split('^')
         ]
         encoded_comp = b'^'.join(groups)
-        validate_pn_component(encoded_comp)
         encoded_comps.append(encoded_comp)
 
     # Remove empty elements from the end
@@ -1448,6 +1643,16 @@ class PersonName:
         """
         return self._name_part(4)
 
+    @property
+    def alphabetic(self) -> str:
+        """Return the first (alphabetic) person name component as a
+        unicode string
+        """
+        try:
+            return self.components[0]
+        except IndexError:
+            return ''
+
     @property
     def ideographic(self) -> str:
         """Return the second (ideographic) person name component as a
@@ -1628,10 +1833,7 @@ class PersonName:
         from pydicom.charset import encode_string, decode_bytes
 
         def enc(s: str) -> bytes:
-            b = encode_string(s, encodings or [default_encoding])
-            validate_value("PN", b, config.settings.writing_validation_mode,
-                           validate_pn_component_length)
-            return b
+            return encode_string(s, encodings or [default_encoding])
 
         def dec(s: bytes) -> str:
             return decode_bytes(s, encodings or [default_encoding], set())
